pub struct CustomCodeSigning {
pub certificate_chain: Option<CodeSigningCertificateChain>,
pub hash_algorithm: Option<String>,
pub signature: Option<CodeSigningSignature>,
pub signature_algorithm: Option<String>,
}Expand description
Describes a custom method used to code sign a file.
Fields
certificate_chain: Option<CodeSigningCertificateChain>The certificate chain.
hash_algorithm: Option<String>The hash algorithm used to code sign the file.
signature: Option<CodeSigningSignature>The signature for the file.
signature_algorithm: Option<String>The signature algorithm used to code sign the file.